==> jc-1.4.0.tar.gz: polyglot/util/Assert__24AssertionFailedError.h <==
// class polyglot.util.Assert$AssertionFailedError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c3e151de254fd037 polyglot_util_Assert__24AssertionFailedError

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_polyglot_util_Assert__24AssertionFailedError_H_
#define _JC_polyglot_util_Assert__24AssertionFailedError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_util_Assert__24AssertionFailedError$sub_refs	_jc_polyglot_util_Assert__24AssertionFailedError$sub_refs;
typedef struct _jc_polyglot_util_Assert__24AssertionFailedError$sub_nonrefs	_jc_polyglot_util_Assert__24AssertionFailedError$sub_nonrefs;
typedef struct _jc_polyglot_util_Assert__24AssertionFailedError$refs	_jc_polyglot_util_Assert__24AssertionFailedError$refs;
typedef struct _jc_polyglot_util_Assert__24AssertionFailedError$nonrefs	_jc_polyglot_util_Assert__24AssertionFailedError$nonrefs;
typedef struct _jc_polyglot_util_Assert__24AssertionFailedError$object	_jc_polyglot_util_Assert__24AssertionFailedError$object;

typedef const struct _jc_polyglot_util_Assert__24AssertionFailedError$vmethods	_jc_polyglot_util_Assert__24AssertionFailedError$vmethods;
typedef const struct _jc_polyglot_util_Assert__24AssertionFailedError$vtable	_jc_polyglot_util_Assert__24AssertionFailedError$vtable;
typedef const struct _jc_polyglot_util_Assert__24AssertionFailedError$vtype	_jc_polyglot_util_Assert__24AssertionFailedError$vtype;

// Constructors
extern void _jc_polyglot_util_Assert__24AssertionFailedError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_Assert__24AssertionFailedError$object *);
extern void _jc_polyglot_util_Assert__24AssertionFailedError$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_util_Assert__24AssertionFailedError$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_polyglot_util_Assert__24AssertionFailedError$vmethods {
};

// Vtable
struct _jc_polyglot_util_Assert__24AssertionFailedError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_polyglot_util_Assert__24AssertionFailedError$vmethods	polyglot_util_Assert__24AssertionFailedError;
};

// Vtype
struct _jc_polyglot_util_Assert__24AssertionFailedError$vtype {
	_jc_type			type;
	_jc_polyglot_util_Assert__24AssertionFailedError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_Assert__24AssertionFailedError$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_util_Assert__24AssertionFailedError$refs {
    _jc_polyglot_util_Assert__24AssertionFailedError$sub_refs	polyglot_util_Assert__24AssertionFailedError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_Assert__24AssertionFailedError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_Assert__24AssertionFailedError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_polyglot_util_Assert__24AssertionFailedError$sub_nonrefs	polyglot_util_Assert__24AssertionFailedError;
};

// Object instance structure
struct _jc_polyglot_util_Assert__24AssertionFailedError$object {
	_jc_polyglot_util_Assert__24AssertionFailedError$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_Assert__24AssertionFailedError$vtype	*vtype;
	_jc_polyglot_util_Assert__24AssertionFailedError$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_Assert__24AssertionFailedError$vtype _jc_polyglot_util_Assert__24AssertionFailedError$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_Assert__24AssertionFailedError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_Assert__24AssertionFailedError$class_object;

#endif	/* _JC_polyglot_util_Assert__24AssertionFailedError_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/Assert__24AssertionFailedError.h <==
// class polyglot.util.Assert$AssertionFailedError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c3e151de254fd037 polyglot_util_Assert__24AssertionFailedError

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_polyglot_util_Assert__24AssertionFailedError_H_
#define _JC_polyglot_util_Assert__24AssertionFailedError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_util_Assert__24AssertionFailedError$sub_refs	_jc_polyglot_util_Assert__24AssertionFailedError$sub_refs;
typedef struct _jc_polyglot_util_Assert__24AssertionFailedError$sub_nonrefs	_jc_polyglot_util_Assert__24AssertionFailedError$sub_nonrefs;
typedef struct _jc_polyglot_util_Assert__24AssertionFailedError$refs	_jc_polyglot_util_Assert__24AssertionFailedError$refs;
typedef struct _jc_polyglot_util_Assert__24AssertionFailedError$nonrefs	_jc_polyglot_util_Assert__24AssertionFailedError$nonrefs;
typedef struct _jc_polyglot_util_Assert__24AssertionFailedError$object	_jc_polyglot_util_Assert__24AssertionFailedError$object;

typedef const struct _jc_polyglot_util_Assert__24AssertionFailedError$vmethods	_jc_polyglot_util_Assert__24AssertionFailedError$vmethods;
typedef const struct _jc_polyglot_util_Assert__24AssertionFailedError$vtable	_jc_polyglot_util_Assert__24AssertionFailedError$vtable;
typedef const struct _jc_polyglot_util_Assert__24AssertionFailedError$vtype	_jc_polyglot_util_Assert__24AssertionFailedError$vtype;

// Constructors
extern void _jc_polyglot_util_Assert__24AssertionFailedError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_Assert__24AssertionFailedError$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_Assert__24AssertionFailedError$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_util_Assert__24AssertionFailedError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_util_Assert__24AssertionFailedError$vmethods {
};

// Vtable
struct _jc_polyglot_util_Assert__24AssertionFailedError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_polyglot_util_Assert__24AssertionFailedError$vmethods	polyglot_util_Assert__24AssertionFailedError;
};

// Vtype
struct _jc_polyglot_util_Assert__24AssertionFailedError$vtype {
	_jc_type			type;
	_jc_polyglot_util_Assert__24AssertionFailedError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_Assert__24AssertionFailedError$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_util_Assert__24AssertionFailedError$refs {
    _jc_polyglot_util_Assert__24AssertionFailedError$sub_refs	polyglot_util_Assert__24AssertionFailedError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_Assert__24AssertionFailedError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_Assert__24AssertionFailedError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_polyglot_util_Assert__24AssertionFailedError$sub_nonrefs	polyglot_util_Assert__24AssertionFailedError;
};

// Object instance structure
struct _jc_polyglot_util_Assert__24AssertionFailedError$object {
	_jc_polyglot_util_Assert__24AssertionFailedError$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_Assert__24AssertionFailedError$vtype	*vtype;
	_jc_polyglot_util_Assert__24AssertionFailedError$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_Assert__24AssertionFailedError$vtype _jc_polyglot_util_Assert__24AssertionFailedError$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_Assert__24AssertionFailedError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_Assert__24AssertionFailedError$class_object;

#endif	/* _JC_polyglot_util_Assert__24AssertionFailedError_H_ */
